@@ -11,7 +11,7 @@ OC.L10N.register(
     "Saved" : "Zapisano",
     "Date added" : "Dodano datę",
     "Link" : "Link",
-    "Tags" : "Tagi",
+    "Tags" : "Etykiety",
     "Description" : "Opis",
     "No bookmarks here." : "Brak tutaj zakładek.",
     "Favorites" : "Ulubione",
@@ -32,7 +32,7 @@ OC.L10N.register(
     "Error parsing the import result" : "Błąd podczas analizowania wyniku importu",
     "Import completed successfully." : "Importowanie zakończone pomyślnie.",
     "Do you really want to delete all your bookmarks?" : "Czy na pewno chcesz usunąć wszystkie swoje zakładki?",
-    "Set tags" : "Ustaw tagi",
+    "Set tags" : "Ustaw etykiety",
     "Failed to import one bookmark, because: " : "Nie można było zaimportować jednej zakładki ponieważ:",
     "No file provided for import" : "Brak pliku do importu",
     "Unsupported file type for import" : "NIewspierany typ pliku importowania",
@@ -47,8 +47,8 @@ OC.L10N.register(
     "Previews" : "Podglądy",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Aby wyświetlać prawdziwe zrzuty ekranu witryn z zakładek, aplikacja Zakładki może korzystać z usług stron trzecich w celu ich wygenerowania.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Możesz zarejestrować się za darmo na <a href=\"http://screeenly.com\">screeenly.com</a> lub <a href=\"https://github.com/stefanzweifel/screeenly\">skonfigurować własny serwer</a>.",
-    "Screenly API URL" : "URL do API Screenly",
-    "Screenly API key" : "Klucz API Screenly",
+    "Screeenly API URL" : "URL API dla Screenly",
+    "Screeenly API key" : "Klucz API dla Screenly",
     "Bookmarks feed" : "Kanał zakładek"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
